#
# spec file for package arts
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           arts
BuildRequires:  alsa-devel
BuildRequires:  audiofile-devel
BuildRequires:  automake
BuildRequires:  glib2-devel
BuildRequires:  jack-devel
BuildRequires:  libdrm-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libvorbis-devel
BuildRequires:  qt3-devel
BuildRequires:  readline-devel
BuildRequires:  update-desktop-files
Obsoletes:      kdelibs3-artsd
Provides:       kdelibs3-artsd
# bug437293
%ifarch ppc64
Obsoletes:      arts-64bit
%endif
#
Summary:        Modular Software Synthesizer
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Players
PreReq:         permissions
Version:        1.5.10
Release:        43.32
Source0:        %{name}-%{version}.tar.bz2
Source1:        artswrapper.7.gz
Source2:        baselibs.conf
Patch2:         no-informational-messages.diff
Patch4:         resmgr-oss.diff
Patch5:         arts-vorbis-fix.dif
Patch7:         fortify_source.patch
Patch8:         arts-start-on-demand.diff
Patch9:         avoid_la_files.diff
Patch10:        arts-allautomakes.diff
Patch11:        arts-glibc27.diff
Patch12:        arts-acinclude.patch
Patch13:        arts-aarch64.diff
Patch14:        arts-automake_add_missing.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A modular software synthesizer that generates realtime audio streams,
includes midi support, is easily extendable, and uses CORBA for
separation of GUI and synthesis.

%package devel
# usefiles /opt/kde3/bin/artsc-config /opt/kde3/bin/mcopidl
Summary:        Include Files and Libraries mandatory for Development.
Group:          Development/Libraries/Other
Provides:       kdelibs3:/opt/kde3/include/artsc/artsc.h
Requires:       alsa-devel
Requires:       arts = %version
Requires:       audiofile-devel
Requires:       glib2-devel
Requires:       jack-devel
Requires:       libogg-devel
Requires:       libstdc++-devel
Requires:       libvorbis-devel
Requires:       qt3-devel

%description devel
A modular software synthesizer that generates realtime audio streams,
supports MIDI, is easily extendable, and uses CORBA for separation of
the GUI and synthesis.

%package gmcop
# usesubdirs gmcop
Summary:        A Modular Software Synthesizer
Group:          Productivity/Multimedia/Sound/Players

%description gmcop
A modular software synthesizer that generates real-time audio streams,
supports midi, is easily extendable, and uses CORBA for separation of
GUI and synthesis.

%prep
%setup -q
%patch2
%if %suse_version < 1010
%patch4
%endif
%patch5
%patch7
%patch8
%patch9
%patch10 -p1
%patch11
%patch12 -p1
%patch13 -p1
%patch14

%build
# no unsermake because of build dependencies hell
sed -i 's|1.5|xxx|g' admin/cvs.sh
make -f admin/Makefile.common cvs
FLAGS="--with-alsa --disable-rpath"
%ifarch s390 alpha
   FLAGS="--without-alsa "
%endif
%if %suse_version < 1030
export PKG_CONFIG_PATH=/opt/gnome/%_lib/pkgconfig/
%endif
CXXFLAGS="$CXXFLAGS $RPM_OPT_FLAGS -DNDEBUG" CFLAGS="$CXXFLAGS" ./configure \
%ifnarch armv4l
    --enable-final \
%endif
    $FLAGS \
    --enable-threading  \
    --prefix=/opt/kde3 \
    --with-qt-dir=/usr/lib/qt3 \
    --libdir=/opt/kde3/%_lib \
    --with-qt-libraries=/usr/lib/qt3/%_lib --disable-debug
%ifarch %ix86
# I trust in arts runtime checking ...
echo "#define HAVE_X86_SSE 1" >> config.h
%endif
#make -C flow/gsl gslconfig.h
make %{?_smp_mflags}

%install
make DESTDIR=$RPM_BUILD_ROOT install
%ifarch x86_64 s390x
mkdir -p $RPM_BUILD_ROOT/opt/kde3/lib/
ln -sf ../lib64/mcop $RPM_BUILD_ROOT/opt/kde3/lib/mcop
%endif
mkdir -p -m 755 $RPM_BUILD_ROOT/%_mandir/man7
cp %SOURCE1 $RPM_BUILD_ROOT/%_mandir/man7/

# Create /etc/ld.so.conf.d/arts.conf - duplicating kdelibs3.conf, which is not here
mkdir -p $RPM_BUILD_ROOT/etc/ld.so.conf.d
cat > $RPM_BUILD_ROOT/etc/ld.so.conf.d/arts.conf <<EOF
/opt/kde3/%_lib
%if "%{_lib}" != "lib"
/opt/kde3/lib
%endif
EOF

%post
/sbin/ldconfig
%set_permissions /opt/kde3/bin/artswrapper

%postun -p /sbin/ldconfig

%post gmcop -p /sbin/ldconfig

%postun gmcop
/sbin/ldconfig
%verifyscript
%verify_permissions -e /opt/kde3/bin/artswrapper

%files
%defattr(-,root,root,755)
%doc COPYING.LIB COPYING
%dir /opt/kde3
%dir /opt/kde3/bin
/opt/kde3/bin/artscat
/opt/kde3/bin/arts[dpsr]*
%verify(not mode) /opt/kde3/bin/artswrapper
%dir /opt/kde3/%_lib
/opt/kde3/%_lib/libarts*.so.*
/opt/kde3/%_lib/libkmedia2*.so.*
/opt/kde3/%_lib/libmcop.so.*
/opt/kde3/%_lib/libmcop_mt.so.*
/opt/kde3/%_lib/libqtmcop.so.*
/opt/kde3/%_lib/libsoundserver_idl.so.*
/opt/kde3/%_lib/libx11globalcomm.so.*
# these need to be in the base package for lt_dlopen()
/opt/kde3/%_lib/*.so
/opt/kde3/%_lib/mcop
%ifarch x86_64 s390x
/opt/kde3/lib
%endif
%{_mandir}/man7/artswrapper.7.gz
%config /etc/ld.so.conf.d/arts.conf

%files gmcop
%defattr(-,root,root)
/opt/kde3/%_lib/libgmcop.so.*

%files devel
%defattr(-,root,root)
/opt/kde3/bin/artsc-config
/opt/kde3/bin/mcopidl
%dir /opt/kde3/include
/opt/kde3/include/*
/opt/kde3/%_lib/*.la

%changelog
* Fri Apr 26 2013 mmeister@suse.com
- Added automake --add-missing option to fix build with new automake
* Tue Mar 19 2013 schwab@suse.de
- Properly determine list of lib64 platforms for ld.so.conf.d script
* Wed Mar  6 2013 matz@suse.com
- Make libtool accept linker scripts as shared libs also on aarch64.
* Sat Jun 16 2012 coolo@suse.com
- add ld.so.conf.d script here, so that mcopidl finds its libraries
* Wed Jun 13 2012 anixx@opensuse.org
- use set_permissions
* Wed Apr 25 2012 anixx@opensuse.org
- fix build with automake 1.11.5 (the script identified 1.11.5 as 1.5)
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Sun Feb 21 2010 coolo@novell.com
- apply patch from fedora to support autoconf >= 2.64
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Mon Jun 15 2009 coolo@novell.com
- take all autotools
- rediff to avoid fuzz
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Aug 20 2008 coolo@suse.de
- update to 1.5.10
  * remove patches sent upstream
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Feb 27 2008 sbrabec@suse.cz
- Fixed artsdsp on bi-arch machines (bnc#71776, kde#158501).
* Wed Feb 13 2008 dmueller@suse.de
- update to 1.5.9:
  * remove patches that are upstreamed
* Wed Nov 28 2007 dmueller@suse.de
- fix build against glibc 2.7
* Mon Oct 22 2007 dmueller@suse.de
- fix build against gcc 4.3
* Tue Oct  9 2007 stbinner@suse.de
- update to 1.5.8 release: stop polling NotificationManager for new
  notifications, instead handle notifications on demand. This gets
  rid of the 50ms timer that was burning energy unnecessarily.
* Wed Sep 19 2007 dmueller@suse.de
- fix arts starting in multiple instances (#178930)
* Mon May 14 2007 stbinner@suse.de
- update to 1.5.7 release (just version bump)
* Wed Apr 18 2007 dmueller@suse.de
- remove some obsolete sections
* Tue Jan 16 2007 stbinner@suse.de
- update to 1.5.6 release (just version bump)
* Fri Nov 10 2006 stbinner@suse.de
- revert to previous version of arts-start-on-demand.diff (#178930)
* Wed Nov  8 2006 stbinner@suse.de
- remove historic "Provides:" (#218798)
* Mon Nov  6 2006 ltinkl@suse.cz
- fix #178930: aRts starts in multiple instances
* Fri Oct 20 2006 dmueller@suse.de
- fix build with automake 1.10
* Tue Oct  3 2006 stbinner@suse.de
- update to 1.5.5 release tarball
* Sun Oct  1 2006 stbinner@suse.de
- update 1_5_BRANCH.diff (endian fix for alsa)
* Sat Sep  9 2006 dmueller@suse.de
- use RPM_OPT_FLAGS
* Thu Sep  7 2006 coolo@suse.de
- resmgr isn't needed on >= 10.1
* Thu Aug 31 2006 stbinner@suse.de
- add man page for artswrapper (#187356)
* Wed Aug 23 2006 stbinner@suse.de
- add 1_5_BRANCH.diff
* Sun Jul 23 2006 coolo@suse.de
- update to aRts 1.5.4:
  * add return value checks for set*uid() functions
* Tue Jul  4 2006 cthiel@suse.de
- fix build
* Wed Jun  7 2006 dmueller@suse.de
- check return values of set*uid (#180223, CVE-2006-2916)
* Wed May 24 2006 stbinner@suse.de
- version number increase to 1.5.3
* Sat May 20 2006 adrian@suse.de
- do not require libdrm-devel for < 10.1
* Mon Mar 20 2006 stbinner@suse.de
- update to 1.5.2
  * Avoid accessing deleted memory.
* Fri Jan 27 2006 dmueller@suse.de
- add patch to avoid .la dependency for lt_dlopen
* Fri Jan 27 2006 dmueller@suse.de
- fix packaging error (#135811)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 21 2006 coolo@suse.de
- update to 1.5.1
* Mon Jan  9 2006 dmueller@suse.de
- require alsa-devel even on s390(x)
* Thu Dec  1 2005 dmueller@suse.de
- update to branch
* Mon Nov 21 2005 stbinner@suse.de
- update to version 1.5 RC 2
* Thu Nov 10 2005 stbinner@suse.de
- update to version 1.5 RC 1
* Wed Oct 12 2005 stbinner@suse.de
- update to version 1.4.92 (1.5 Beta 2)
* Fri Sep 16 2005 stbinner@suse.de
- update to version 1.4.91 (1.5 Beta)
* Mon Aug 29 2005 dmueller@suse.de
- fix arts when using $TMPDIR (#113564)
* Wed Aug 17 2005 coolo@suse.de
- let arts start it self
- pleasing the libtool check
* Thu Jul 21 2005 coolo@suse.de
- update to version 1.4.2
* Thu Jul  7 2005 dmueller@suse.de
- fix build
* Tue May 24 2005 adrian@suse.de
- update to version 1.4.1
* Tue Apr 19 2005 coolo@suse.de
- don't use debug
* Mon Apr 18 2005 coolo@suse.de
- update admin for gcc4
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Wed Mar 16 2005 adrian@suse.de
- clean up /tmp dir after ending (#71976, by Waldo)
* Wed Mar  9 2005 coolo@suse.de
- adding patch by Waldo to avoid problems on resume from RAM
* Sat Mar  5 2005 adrian@suse.de
- update to 3.4.0 final
* Sat Feb 26 2005 adrian@suse.de
- update to 3.4.0 RC1
* Fri Feb 25 2005 adrian@suse.de
- add resmgr support for oss output
* Thu Feb 24 2005 adrian@suse.de
- update to version 3.4.0 RC1, first try
- remove unneeded unsermake from nfb
* Mon Feb 21 2005 adrian@suse.de
- update to current snapshot
* Mon Feb 14 2005 adrian@suse.de
- update from CVS
* Fri Feb 11 2005 adrian@suse.de
- update from CVS
* Mon Feb  7 2005 adrian@suse.de
- update to beta 2
* Tue Feb  1 2005 adrian@suse.de
- default to oss again due to problems with alsa on 64bit
* Fri Jan 28 2005 adrian@suse.de
- update to current snapshot
* Thu Jan 20 2005 adrian@suse.de
- update to current snapshot
* Wed Jan 19 2005 coolo@suse.de
- fixing requirements of the installed .la files
* Sun Jan  9 2005 adrian@suse.de
- final beta1
* Tue Jan  4 2005 coolo@suse.de
- update to beta1 snapshot
* Tue Dec 14 2004 coolo@suse.de
- next update to HEAD to fix the next compilation problem
* Fri Dec 10 2004 adrian@suse.de
- update to current HEAD to fix compilation problems in other
  applications
* Wed Dec  8 2004 adrian@suse.de
- update to official 3.4 alpha 1
* Mon Dec  6 2004 adrian@suse.de
- update to KDE head snapshot
* Mon Nov 29 2004 adrian@suse.de
- update to version 1.3.2
* Tue Oct 12 2004 adrian@suse.de
- update to version 1.3.1
* Thu Sep 30 2004 adrian@suse.de
- remove Requires: mad-devel from arts-devel
* Sun Aug 29 2004 adrian@suse.de
- remove mad support, we use akode from kdemultimedia instead
* Mon Aug 16 2004 adrian@suse.de
- update to version 1.3.0
* Tue Aug 10 2004 adrian@suse.de
- update to version 1.3.0 RC2
* Fri Aug  6 2004 adrian@suse.de
- update to version 1.3.0 RC1
* Mon Aug  2 2004 adrian@suse.de
- accept automake 1.9
* Mon Jul 19 2004 adrian@suse.de
- update to version 3.2.92 (KDE 3.3 beta 2)
* Sat Jun 26 2004 adrian@suse.de
- update to version 3.2.91 (KDE 3.3 beta 1)
  * enable support for jack
* Mon May 31 2004 adrian@suse.de
- update to version 1.2.3 (for KDE 3.2.3 release)
* Mon Apr 19 2004 coolo@suse.de
- adding requirements so the .la files point to existant files
* Wed Apr 14 2004 adrian@suse.de
- update to version 1.2.2
* Sat Apr  3 2004 ro@suse.de
- remove wrong hunk from alsa-default.diff
* Thu Apr  1 2004 adrian@suse.de
- official enabled alsa output again (patch got anyway applied before)
* Thu Apr  1 2004 tiwai@suse.de
- fixed the high CPU usage of ogg/vorbis and mp3 (bug #37855).
  increasing cache size and disabled padding.
- suppress debug messages.
* Tue Mar 23 2004 adrian@suse.de
- apply 64bit aliasing fix from Matz (#36653)
* Mon Mar  1 2004 coolo@suse.de
- update to version 1.2.1
* Sun Feb 29 2004 adrian@suse.de
- use oss output as default again
  (alsa output is known to be broken atm. b.k.o #30651)
* Tue Feb 24 2004 adrian@suse.de
- suppress informational messages
* Mon Jan 26 2004 adrian@suse.de
- update to version 1.2.0 ( KDE 3.2 final )
* Sun Jan 18 2004 adrian@suse.de
- update to version 1.1.95 ( KDE 3.2 RC1 )
* Tue Jan 13 2004 adrian@suse.de
- update to snapshot 2004011309
* Tue Dec 30 2003 adrian@suse.de
- update to snapshot 2003123011
* Mon Dec 15 2003 adrian@suse.de
- update to snapshot 2003121511
- accept automake 1.8
* Mon Dec  1 2003 adrian@suse.de
- update to 1.1.94 ( KDE 3.2 beta 2 )
* Thu Nov 13 2003 adrian@suse.de
- update to new snapshot from 2003102409
* Wed Oct 29 2003 adrian@suse.de
- update to 3.2 beta 1
* Tue Oct 21 2003 adrian@suse.de
- update to snapshot 2003102008
* Sun Oct  5 2003 adrian@suse.de
- update to snapshot 2003100510
* Tue Sep 30 2003 adrian@suse.de
- update to 1.1.92_2003093009
  * last tar ball was broken
* Mon Sep 29 2003 adrian@suse.de
- update to version 1.1.92 (KDE 3.2 alpha 2)
* Mon Sep  8 2003 adrian@suse.de
- update to version 1.1.4
* Tue Sep  2 2003 coolo@suse.de
- fixing artsdsp (most likely cause for #29358)
* Wed Aug 20 2003 adrian@suse.de
- fix again for x86_64 (based on Takashis patch)
- prefer alsa over oss, if avaible
* Tue Jul 29 2003 adrian@suse.de
- fix build on lib64
* Tue Jul 29 2003 adrian@suse.de
- add support for gmcop again
- fix build for < 8.0
* Tue Jul 22 2003 coolo@suse.de
- don't strip
* Thu Jul 17 2003 adrian@suse.de
- remove temporary hacks again
* Tue Jul 15 2003 adrian@suse.de
- update to version 1.1.3 (KDE 3.1.3)
- add some temporary hacks for > 8.2 (qt 3.2)
* Thu Jun 12 2003 coolo@suse.de
- package directories
- run ldconfig like mad
* Wed May  7 2003 adrian@suse.de
- update to version 1.1.2 (for KDE 3.1.2)
* Thu Apr 10 2003 adrian@suse.de
- fix build for 8.0
* Mon Apr  7 2003 ro@suse.de
- fix head calling syntax in admin tarball
* Tue Mar 11 2003 adrian@suse.de
- update to version 1.1.1 second try
  * minor memory/crash fix
- sync admin tar ball with kdelibs
* Tue Mar  4 2003 adrian@suse.de
- add missing Provides kdelibs-artsd
* Mon Mar  3 2003 coolo@suse.de
- fixing configure check for non-32bit architectures
* Mon Mar  3 2003 adrian@suse.de
- update to version 1.1.1
  * all changes were already in 1_1_BRANCH patch
* Mon Feb 24 2003 adrian@suse.de
- remove -mminimal-toc
* Fri Jan 17 2003 adrian@suse.de
- use official 1.1 tar ball, which will be released with KDE 3.1
* Mon Nov 25 2002 adrian@suse.de
- update to RC5
* Sat Nov 23 2002 adrian@suse.de
- fix build for < SuSE 8.1
* Tue Nov 19 2002 adrian@suse.de
- update to version 1.1.0-final
- fix build on x86_64
* Sun Nov  3 2002 adrian@suse.de
- update to version 1.1.0.20021030 ~= RC1
* Mon Oct  7 2002 adrian@suse.de
- update to version 3.0.4
* Thu Aug  8 2002 adrian@suse.de
- fix configure parameters
* Wed Aug  7 2002 adrian@suse.de
- update to new 1.0.3 tar ball which comes with KDE 3.0.3
- update admin tar ball
* Wed Jul 31 2002 tiwai@suse.de
- fixed weird sound output on x86-64 (bug #17295).
* Tue Jul 23 2002 adrian@suse.de
- add support for gnome/glib 2.0 in -gmcop subpackage
- add support for vorbis
* Wed Jul 17 2002 meissner@suse.de
- compile with -mminimal-toc on ppc64
* Mon Jul  8 2002 adrian@suse.de
- fix security problem with arts
  * update to 1.0.3:
    using setuid instead of seteuid in artswrapper, so a exploited
    artsd can not get root again.
* Thu Jun 27 2002 adrian@suse.de
- move mcopidl to -devel package
- use %%run_ldconfig
* Mon Jun 24 2002 adrian@suse.de
- update to version 1.0.2
* Wed Jun 19 2002 uli@suse.de
- disable final on ARM
* Fri Jun  7 2002 adrian@suse.de
- use same admin tar ball as in kdelibs3
- using fixed libtool for -m32/-m64 (fixed by matz)
* Thu May  9 2002 adrian@suse.de
- update to version 1.0.1 (part of KDE 3.0.1 bug-fix release)
* Thu May  2 2002 meissner@suse.de
- enhanced varargs handling to be more generic (using __va_copy)
* Tue Apr  2 2002 ro@suse.de
- work around automake problem
* Mon Mar 25 2002 adrian@suse.de
- use second try of version 1.0.0
* Mon Mar 25 2002 adrian@suse.de
- update to version 1.0.0 (KDE 3.0 final)
* Thu Mar 21 2002 adrian@suse.de
- update to version 0.9.9 (for KDE 3.0rc3)
* Sun Mar 10 2002 adrian@suse.de
- update to version 0.9.8 (for KDE 3.0rc2)
* Mon Mar  4 2002 adrian@suse.de
- update to snapshot 0.7.1.2002030321
* Mon Feb 25 2002 adrian@suse.de
- update to snapshot 0.7.1.2002022512
* Mon Feb 18 2002 adrian@suse.de
- update to snapshot 0.7.1.2002021810
* Thu Feb 14 2002 adrian@suse.de
- update to snapshot 0.7.1.2002021421
* Wed Feb 13 2002 adrian@suse.de
- split arts from kdelibs3 package
- using a 0.7.1 snapshot
* Mon Feb 11 2002 adrian@suse.de
- update to snapshot 2.92.2002021111
* Mon Feb  4 2002 adrian@suse.de
- update to 2.92 (KDE 3.0 beta 2)
- create common_compile_flags file
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Jan 28 2002 adrian@suse.de
- update to snapshot from 2.91.2002012811
* Wed Jan 23 2002 adrian@suse.de
- add missing header files
* Tue Jan 22 2002 adrian@suse.de
- update to snapshot 2.91.2002012221
* Tue Jan 15 2002 adrian@suse.de
- update to snapshot 2.91.2002011511
* Sat Jan  5 2002 adrian@suse.de
- update to recent/todays snapshot
- disable rpath for SuSE > 7.3
  (/opt/kde3/lib is in ld.so.conf)
- add Requires: line for at least Qt 3.0.1
* Mon Dec 17 2001 adrian@suse.de
- fix compile on s390
- add fix for khtml seg fault
- do not build documentation for <7.3 distributions until kdoc
  is fixed
* Wed Dec 12 2001 adrian@suse.de
- update to KDE 3.0 Beta 1
* Tue Dec  4 2001 adrian@suse.de
- use current CVS snapshot
* Fri Nov  2 2001 adrian@suse.de
- using cvs snapshot from 01 Nov 2001
* Sat Oct 20 2001 adrian@suse.de
- using newer cvs-snapshot
  (compiles again with qt 3 final)
* Tue Oct  9 2001 adrian@suse.de
- branch to first kdelibs 3 (alpha 1)
* Sun Sep 23 2001 adrian@suse.de
- add security fix for peer-ssl from Dirk
- add fix to make it possible to allow JS from local pages
* Fri Sep 21 2001 adrian@suse.de
- add fix for kbuildsycoca --incremental from Waldo
  (changed files (due to updated packages or a SuSEconfig run for
  example) do not lead anymore to an incorrect ksycoca database.
* Tue Sep 18 2001 adrian@suse.de
- add symbolic link to /opt/kde2/doc/HTML/en/kdeapi
- #neededforbuild cups -> cups-libs
* Sat Sep 15 2001 adrian@suse.de
- add klineedit fix
- add warning that kdDebug function is disabled (except for ppc)
- fix kdelibs-2.2.1.dif (do not apply patch for ppc-only global)
* Thu Sep 13 2001 adrian@suse.de
- add fix for kjs (octal parsing)
- add fix icondialog (custom icon directorys)
- fix ia64 patch
* Tue Sep 11 2001 adrian@suse.de
- add security fixes for kssl (do not save keys on disk)
- add Qt API to the API index page
* Mon Sep 10 2001 adrian@suse.de
- update to to second try of kdelibs 2.2.1 tar ball
  * JavaScript fixes
- fix ia64 workarounds to build on older distris
* Sun Sep  9 2001 schwab@suse.de
- Fix specfile for ia64 workarounds.
* Sat Sep  8 2001 adrian@suse.de
- updating to final 2.2.1 tar ball
* Sun Sep  2 2001 adrian@suse.de
- update to KDE_2_2_BRANCH from 02.09.2001
  * compile fixes
  * KFile crash fix
  * KDockWidget crash fix, caused crash in quanta
  * fix login with chars in password >127
  * load charsets file on demand
  * kxmlgui fixed to read really the complete xml file.
- drop -cups package, the cups libs are now splitted from the cups
  package.
- add kmimetype hack to get a fallback application for device icons
- make KDE quiet by default (kdDebug default value is 4 now)
* Tue Aug 28 2001 adrian@suse.de
- update to KDE_2_2_BRANCH from 28.08.2001
  * fix kspell for iso 13 languages
  * fix $PATH for kdesu
  * check the preview action in setPreviewWidget()
  * check for aborted save
  * official patch for kbuildsycoca
  * kfile fixes
  * crash fixes in userstylesheets
  * large file system support fix
  * crash fix in kbugreport
- removed patches for kbuildsycoca and large file support
* Sat Aug 25 2001 adrian@suse.de
- update to KDE_2_2_BRANCH from 25.08.2001
  * khtml supports <META http-equiv="Cache-Control" content="no-cache">
  * kded updates
  * translation updates
- kbuildsycoca speed optimisation
  (original patch from Lubos Lunak, reworked to be BC)
* Tue Aug 21 2001 adrian@suse.de
- using KDE_2_2_BRANCH from 21.08.2001
  * html parser fixes
  * artsd fixes
  * ...
- disable FAM by default, it can be enabled with
  export USE_FAM=1
- disable and obsolete -i686 package, until the number of problems
  are solved
* Mon Aug  6 2001 adrian@suse.de
- add assert into khtml/misc/loader.cpp as recomended by Dirk
- switch on SSE support in i386 architecture
  (arts has a runtime checking)
- clean up file list
- ia64 workarounds
* Mon Aug  6 2001 adrian@suse.de
- update to final 2.2
* Wed Aug  1 2001 adrian@suse.de
- update to 2.2rc1
* Fri Jul  6 2001 adrian@suse.de
- generate API documentation
  (no need to install kdevelop for api docu anymore)
* Fri Jun 29 2001 adrian@suse.de
- 2.2beta1
* Mon May 28 2001 adrian@suse.de
- 2.2alpha2
* Mon Apr 16 2001 adrian@suse.de
- 2.2alpha1
* Fri Apr 13 2001 adrian@suse.de
- add currency symbol to KFontDialog preview for testing purposes
* Tue Apr 10 2001 adrian@suse.de
- revert also kdeinit changes (compile fix)
- add fixes for javascript from CVS
- add fixes for font name mapping from CVS
- add kdeinit_shutdown patch from Waldo
* Mon Apr  9 2001 adrian@suse.de
- minor fix, but hopefully fix linker problems on all P-II systems
* Mon Apr  9 2001 adrian@suse.de
- disable alsa for 7.0-ppc
* Fri Apr  6 2001 adrian@suse.de
- drop the -nostdlib flag during linking. this causes problems
  (since not all need libs are used) on some architectures
- -O2 for axp
* Thu Apr  5 2001 adrian@suse.de
- update to 2_1_BRANCH.
  this fixes the proxy server authentication problem
* Wed Mar 28 2001 adrian@suse.de
- disable ssl support for 7.0-ppc
  (problems with the compiler and linker, which can not be fixed
  without to loss the BC)
* Tue Mar 27 2001 ro@suse.de
- changed neededforbuild <docbkdsl> to <docbook-dsssl-stylesheets>
* Tue Mar 20 2001 adrian@suse.de
- enable -O2 for ppc
  using inline gcc bug workaround for ia64
* Tue Mar 20 2001 adrian@suse.de
- update to 2.1.1 (official tar ball)
* Mon Mar 19 2001 adrian@suse.de
- update to current 2_1_BRANCH
  we have kde-config as executable binary back
  (lots of configure scripts test this)
* Mon Mar 19 2001 adrian@suse.de
- add cyrus-sassl to #neededforbuild
* Sat Mar 17 2001 adrian@suse.de
- added missing packages in #neededforbuild
* Sat Mar 17 2001 adrian@suse.de
- fix CATALOG for distributions <7.2
  update to current 2_1_0_TAG
* Tue Mar 13 2001 ro@suse.de
- added CATALOG for docbook_3
* Tue Mar 13 2001 ro@suse.de
- changed neededforbuild <docbk30> to <docbook_3>
* Thu Feb 22 2001 adrian@suse.de
- the final final 2.1.0 tar ball ...
* Wed Feb 21 2001 adrian@suse.de
- use the right KDE BRANCH (not my fault ;-)
* Wed Feb 21 2001 adrian@suse.de
- update to final 2.1.0
* Wed Feb 14 2001 adrian@suse.de
- update to 2.1 post beta 2
* Mon Jan 22 2001 stepan@suse.de
- alpha axp compile fixes for gcc 2.95.2
* Tue Jan 16 2001 adrian@suse.de
- add a check of return value in kprocess.
  Hopefully no crashes anymore.
* Mon Jan 15 2001 adrian@suse.de
- disable --enable-final until the glibc/compiler problem in
  kprocess is fixed
* Mon Jan 15 2001 adrian@suse.de
- fix index.desktop for distris <7.1
* Sat Jan 13 2001 adrian@suse.de
- fix local support in kicker. native language again in menus
  this fix does not work for chinese people
  fix index.desktop in highcolor, 22x22 actions icons can be loaded
  again
* Thu Jan 11 2001 adrian@suse.de
- create some links to see the konqueror gear again
  fix hicolor index file
* Tue Jan  9 2001 adrian@suse.de
- added security fix for kdesu from Waldo
* Mon Jan  8 2001 adrian@suse.de
- fix SuSE icon description
* Sun Jan  7 2001 adrian@suse.de
- use additional pathes, to not conflict with older pathes
* Sun Jan  7 2001 adrian@suse.de
- new icon handling. much more clean now and the
  dependencie to icons is not needed anymore
* Sat Jan  6 2001 adrian@suse.de
- fix locale support.
  LANG=de_DE or LANG=de_DE.utf-8 is working now.
* Tue Jan  2 2001 adrian@suse.de
- added a fix for font handling, if antialising is used
  (Thanks Kurt)
* Mon Jan  1 2001 adrian@suse.de
- remove charset for german. this confuses the font handling
  added fix for stalled, but broken connections; thanks waldo
* Sat Dec 30 2000 adrian@suse.de
- extend rpm mimelnk for *.spm files
  disabled threading
* Wed Dec 27 2000 adrian@suse.de
- drop message in kdeinit, which produce a lot of invalid bugzilla entrys
* Wed Dec 20 2000 adrian@suse.de
- added openssl-devel for #neededforbuild
* Sun Dec 17 2000 adrian@suse.de
- moved icon links back to kdelibs :-(
* Sun Dec 17 2000 adrian@suse.de
- moved icon links from this package to kdebase
* Fri Dec 15 2000 adrian@suse.de
- brown paper bag fix ... I spend Rudi a beer ...
* Fri Dec 15 2000 adrian@suse.de
- added icon packages to #neededforbuild
* Thu Dec 14 2000 adrian@suse.de
- fixed specfile
* Wed Dec 13 2000 adrian@suse.de
- fixed icon links
* Wed Dec 13 2000 adrian@suse.de
- update to current 2_0_BRANCH
* Wed Nov 29 2000 adrian@suse.de
- update to 2.0.1
* Wed Nov 22 2000 ro@suse.de
- remove penguin.png (in kdebase)
* Tue Nov 21 2000 adrian@suse.de
- fixed /etc/kderc
* Mon Nov 20 2000 adrian@suse.de
- added icon support for non kde icons
  added /etc/kderc
  ~/Desktop -> ~/KDesktop
* Thu Nov 16 2000 adrian@suse.de
- update to newer snapshot from KDE_2_0_BRANCH
  fixed sgml catalog file for our sgml enviroment
* Fri Nov  3 2000 adrian@suse.de
- fixed needed for build
* Thu Nov  2 2000 adrian@suse.de
- fixed file list
* Tue Oct 17 2000 adrian@suse.de
- update to 2.0.0
- changed default for ~/.kde to ~/.kde2
- dropped klibs2i and klibs2cr again
- splitted package in
  * kdelibs
  * kdelibs-devel
* Wed Sep 20 2000 adrian@suse.de
- the last fix :-(
* Sat Sep 16 2000 adrian@suse.de
- splited klibs2 into klibs2, klibs2i (international version
  without crypt support) and klibs2cr (crypt version)
* Sat Sep 16 2000 adrian@suse.de
- removed ssl/ssh support
  added big endian fix in KPixmap
* Tue Sep 12 2000 adrian@suse.de
- changed to -O0 for ppc and alpha
* Tue Sep 12 2000 adrian@suse.de
- update to RC 1
* Mon Aug 21 2000 adrian@suse.de
- update to beta 4
* Mon Jul 24 2000 adrian@suse.de
- update to second version of beta 3
* Fri Jul 21 2000 adrian@suse.de
- update to beta 3
* Mon Jul 17 2000 adrian@suse.de
- update to snapshot from 17.07.2000
* Thu Jul  6 2000 adrian@suse.de
- Spec file created from kdelibs-1.91.20000706.tar.gz by autospec
* Fri Jun  9 2000 adrian@suse.de
- correct neededforbuild and updated khtml
* Fri Jun  9 2000 adrian@suse.de
- update to 1.91; beta 2
* Mon Jun  5 2000 adrian@suse.de
- snapshot from 06.06.2000
* Sun May 28 2000 adrian@suse.de
- snapshot from 28.05.2000
  new type of spec file
* Fri May 12 2000 adrian@suse.de
- update to KDE 1.90
* Thu Apr 27 2000 adrian@suse.de
- snapshot from 25.04.2000
* Thu Apr 20 2000 adrian@suse.de
- fixed file list
* Wed Apr 19 2000 adrian@suse.de
- snapshot from 17.04.2000
* Thu Apr  6 2000 adrian@suse.de
- snapshot from 06.04.2000
* Thu Mar 30 2000 adrian@suse.de
- first KDE libs 2 package. PRE 1.90 Version
